# repo\_state #

This repository defines two executable tools (linux only):  save\_repo\_state and enforce\_repo\_state.  These tools are intended to capture the state of multiple git repositories and save that state to a file, and then later enforce the state specified in the file onto a set of git repos. 

## Usage ##

Each tool supports the -h and --help flags. 

```
$ save\_repo\_state --help

$ enforce\_repo\_state --help
```

## License ##

See LICENSE.txt


## Who do I talk to? ##

Jeff Gable  jeff@promenadesoftware.com
